import transitfit
import platform
from pathlib import Path
import time

start_time = time.perf_counter()

outpath = './TransitFit_results'

# Add input_data, priors and filterpath
input_data = './input_data.csv'
filterpath = './filterpath.csv'
priors = './priors.csv'

detrending_limits = [[-10, 10]]  # , [-10, 10]]#, [-22, 22]]

host_T = (5500.0, 150.0)
host_logg = (4.25, 0.15)
host_z = (0.14, 0.19)
host_r = (1.05, 0.05)

normalise_limits = [0.95, 1.05]

print("\n\n=== The Great JWST Exoplanet Challenge ===\n\n")
print(f"Running on python version: {platform.python_version()}")
print(f'Using TransitFit version: {transitfit.__version__}')
#print(f'Dynesty version {dynesty.__version__}')
print(f"Output will be saved in the folder {outpath}")
print(f"Some additional files will get downloaded for the analysis.")
print(f"\nKindly ignore if this message is displayed while running the code: \"WARNING:root:Too few points to create valid contours\"\n\n")

Path(outpath).mkdir(parents=True, exist_ok=True)

results = transitfit.run_retrieval(input_data,
                                    priors,
                                    filterpath,
                                    host_T=host_T,
                                    host_logg=host_logg,
                                    host_z=host_z,
                                    host_r=host_r,
                                    cadence=120 / 60,
                                    walks=100,
                                    slices=10,
                                    nlive=300,
                                    allow_ttv=False,
                                    detrending_list=[['nth order', 2]],
                                    dynesty_sample='rslice',
                                    limb_darkening_model='quadratic',
                                    ld_fit_method='coupled',
                                    ldtk_cache='cache',
                                    max_batch_parameters=25,
                                    batch_overlap=2,
                                    #dlogz=0.00309,
                                    maxiter=None,
                                    maxcall=None,
                                    dynesty_bounding='multi',
                                    normalise=True,
                                    detrend=True,
                                    detrending_limits=detrending_limits,
                                    results_output_folder=outpath,
                                    final_lightcurve_folder=outpath+'/fitted_lightcurves',
                                    plot_folder=outpath+'/plots',
                                    plot=None,
                                    marker_color='dimgray',
                                    line_color='black',
                                    bin_data=True,
                                    binned_color='red',
                                    n_procs=1,
                                    normalise_limits=normalise_limits,
                                    check_batchsizes=False)

print(f"Time taken for the analysis: {time.perf_counter()-start_time:.2f} seconds")
print(f"\nThank you for participating. To share your results, please send us: \n\t1. The 'summary_output.csv' file (you can find it inside the TransitFit_results folder), and \n\t2. The wavelength you chose (the name of this folder has some numbers which refer to the wavelength).")
